#[non_exhaustive]pub struct Request {
pub room_id: OwnedRoomId,
pub event_type: MessageLikeEventType,
pub txn_id: OwnedTransactionId,
pub body: Raw<AnyMessageLikeEventContent>,
pub timestamp: Option<MilliSecondsSinceUnixEpoch>,
pub sticky_duration_ms: Option<StickyDurationMs>,
}client or server only.Expand description
Request type for the create_message_event endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.room_id: OwnedRoomIdThe room to send the event to.
event_type: MessageLikeEventTypeThe type of event to send.
txn_id: OwnedTransactionIdThe transaction ID for this event.
Clients should generate a unique ID across requests within the same session. A session is identified by an access token, and persists when the access token is refreshed.
It will be used by the server to ensure idempotency of requests.
body: Raw<AnyMessageLikeEventContent>The event content to send.
timestamp: Option<MilliSecondsSinceUnixEpoch>Timestamp to use for the origin_server_ts of the event.
This is called timestamp massaging and can only be used by Appservices.
Note that this does not change the position of the event in the timeline.
sticky_duration_ms: Option<StickyDurationMs>unstable-msc4354 only.The duration to stick the event for.
Valid values are the integer range 0-3600000 (1 hour). The presence of this field indicates that the event should be sticky, this will give this event additional delivery guarantees.
Caller must first check that the server supports sticky events (via /versions),
or it will be no-op.
Implementations
Sourceimpl Request
impl Request
Sourcepub fn new<T>(
room_id: OwnedRoomId,
txn_id: OwnedTransactionId,
content: &T,
) -> Result<Self>where
T: MessageLikeEventContent,
pub fn new<T>(
room_id: OwnedRoomId,
txn_id: OwnedTransactionId,
content: &T,
) -> Result<Self>where
T: MessageLikeEventContent,
Sourcepub fn new_raw(
room_id: OwnedRoomId,
txn_id: OwnedTransactionId,
event_type: MessageLikeEventType,
body: Raw<AnyMessageLikeEventContent>,
) -> Self
pub fn new_raw( room_id: OwnedRoomId, txn_id: OwnedTransactionId, event_type: MessageLikeEventType, body: Raw<AnyMessageLikeEventContent>, ) -> Self
Creates a new Request with the given room id, transaction id, event type and raw event
content.